//-----------------------------------------------------------------------------
// Edge_Mesh.fx
//
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Parameters
//-----------------------------------------------------------------------------
float4x4 Transform : WorldViewProjection;
float4x4 ModelWorld : World;
float4 CamPosition : ViewPosition;

float4 scale : ViewParm0 = float4(0.1,0.1,0.1,0.1); 
//-----------------------------------------------------------------------------
// Structures
//-----------------------------------------------------------------------------
struct vertex
{
    float3 position	: POSITION;
    float3 normal   : NORMAL;
    float3 tangent  : TANGENT;
	float  ridge    : TEXCOORD0;
};
//-----------------------------------------------------------------------------
struct fragment
{
    float4 position : POSITION;
	float4 color    : COLOR;
};
//-----------------------------------------------------------------------------
struct pixel
{
	float4 color : COLOR;
};
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Vertex shaders
//-----------------------------------------------------------------------------
fragment VS( vertex IN )
{
    fragment OUT;

	float4 WorldPos = mul( float4(IN.position, 1), ModelWorld );
	float3 P = WorldPos.xyz; 
	
	float3 N = mul(IN.normal, (float3x3)ModelWorld);	// world space face 1 normal
	float3 T = mul(IN.tangent, (float3x3)ModelWorld);	// world space face 2 normal
	float3 E = P - CamPosition.xyz;				// un-normalized world space eye to position

	OUT.color = 0;

	float EdotN = dot(E,N);		// positive for forward facing, negative for back facing
	float EdotT = dot(E,T);		// positive for forward facing, negative for back facing

	//float extend = 0.1 * (length(E) / 75);
	float extend = scale.x * (length(E) / 75);

	float3 newPos = IN.position + IN.normal * extend;


	if ( ( EdotN * EdotT ) < 0 )		// silhouette detection
	{
		OUT.color.a = 1;			// make this visible
		if ( EdotN > 0 )			// extend only the front facing vertices
		{					// in the opposite direction
			newPos = IN.position-IN.normal*extend;
		}
	}

	OUT.color.a += IN.ridge;		// set visibility for ridges and valleys (pre-computed)

	OUT.position = mul( float4( newPos, 1), Transform );	// output the final vertex position

	return OUT;
}
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Pixel Shader
//-----------------------------------------------------------------------------
pixel PS( fragment IN )
{
	pixel OUT;

	OUT.color = IN.color;

	return OUT;
}

//-----------------------------------------------------------------------------
// Techniques
//-----------------------------------------------------------------------------

technique EdgeMesh
{
    pass P0
    {
		AlphaTestEnable = true;
		AlphaRef = 0x00000001;
	      AlphaFunc = Greater;

		VertexShader = compile vs_1_1 VS();
		PixelShader  = compile ps_1_1 PS();
    }
}
//-----------------------------------------------------------------------------