//-----------------------------------------------------------------------------
// Effect File Variables
//-----------------------------------------------------------------------------

texture Tex : ColorMap0;

sampler Sampler0 = sampler_state
{
    Texture   = (Tex);
    MipFilter = Linear;
    MinFilter = Linear;
    MagFilter = Linear;
    AddressU = Clamp;
    AddressV = Clamp;
};

//-----------------------------------------------------------------------------
// Vertex Definitions
//-----------------------------------------------------------------------------

struct vertex
{
	float3 position : POSITION;
	float2 texcoord : TEXCOORD0;
	float4 color    : COLOR;
};

struct fragment
{
	float4 position : POSITION;
	float2 texcoord : TEXCOORD0;
	float4 color    : COLOR;
};

struct pixel
{
	float4 color : COLOR;
};

//-----------------------------------------------------------------------------
// Simple Vertex Shader
//-----------------------------------------------------------------------------

fragment VS( vertex IN )
{
	fragment OUT;

	OUT.position = float4(IN.position.x, IN.position.y, 0.0, 1.0);
	OUT.texcoord = IN.texcoord;
	OUT.color = IN.color;

	return OUT;
}

//-----------------------------------------------------------------------------
// Simple Pixel Shader
//-----------------------------------------------------------------------------

pixel PS( fragment IN )
{
	pixel OUT;

	OUT.color = tex2D( Sampler0, IN.texcoord ) * IN.color;
	
	return OUT;
}

//-----------------------------------------------------------------------------
// Image Processing Technique
//-----------------------------------------------------------------------------

technique Thresh
{
	pass Pass0
	{
//		AlphaTestEnable = true;
//		AlphaRef = 0x00000005;
//		AlphaFunc = Greater;
    
		AlphaBlendEnable = True;
		SrcBlend = SrcAlpha; //One;
		DestBlend = InvSrcAlpha;

		VertexShader = compile vs_1_1 VS();
		PixelShader  = compile ps_1_1 PS();
	}
}

